# pyAmbiclimate [![Build Status](https://travis-ci.org/Danielhiversen/pyAmbiclimate.svg?branch=master)](https://travis-ci.org/Danielhiversen/pyAmbiclimate)
Python library to communicate with ambiclimate
